@@ -1441,8 +1441,14 @@ PlaybackConfigurationTypeDef = TypedDict(
     total=False,
 )
 
-PutPlaybackConfigurationRequestRequestTypeDef = TypedDict(
-    "PutPlaybackConfigurationRequestRequestTypeDef",
+_RequiredPutPlaybackConfigurationRequestRequestTypeDef = TypedDict(
+    "_RequiredPutPlaybackConfigurationRequestRequestTypeDef",
+    {
+        "Name": str,
+    },
+)
+_OptionalPutPlaybackConfigurationRequestRequestTypeDef = TypedDict(
+    "_OptionalPutPlaybackConfigurationRequestRequestTypeDef",
     {
         "AdDecisionServerUrl": str,
         "AvailSuppression": AvailSuppressionTypeDef,
@@ -1452,7 +1458,6 @@ PutPlaybackConfigurationRequestRequestTypeDef = TypedDict(
         "DashConfiguration": DashConfigurationForPutTypeDef,
         "LivePreRollConfiguration": LivePreRollConfigurationTypeDef,
         "ManifestProcessingRules": ManifestProcessingRulesTypeDef,
-        "Name": str,
         "PersonalizationThresholdSeconds": int,
         "SlateAdUrl": str,
         "Tags": Mapping[str, str],
@@ -1462,6 +1467,14 @@ PutPlaybackConfigurationRequestRequestTypeDef = TypedDict(
     total=False,
 )
 
+
+class PutPlaybackConfigurationRequestRequestTypeDef(
+    _RequiredPutPlaybackConfigurationRequestRequestTypeDef,
+    _OptionalPutPlaybackConfigurationRequestRequestTypeDef,
+):
+    pass
+
+
 PutPlaybackConfigurationResponseTypeDef = TypedDict(
     "PutPlaybackConfigurationResponseTypeDef",
     {
